ActivatedListener

Struct ActivatedListener 

pub(crate) struct ActivatedListener {
    conn: Option<Connection<Stream>>,
}
A Listener that yields a single pre-connected socket, then blocks forever.

Used for socket activation where a connected socket pair is passed on fd 3. After the first accept() returns the connection, subsequent calls pend indefinitely (the server will be killed by the parent process once the connection closes).

Fields

conn: Option<Connection<Stream>>

The connection to yield on the first accept(), consumed after use.