pub struct MountParams {
pub overlay: Option<bool>,
pub read_write: Option<bool>,
}Expand description
Options for a Mount call. All fields are optional for forward
compatibility — new mount options can be added without breaking the
wire format.
Fields
overlay: Option<bool>Whether to set up an overlayfs upper layer. When true, the fd array must contain two fds: upperdir and workdir.
read_write: Option<bool>Whether to mount read-write (only meaningful with overlay).
Implementations
Sourceimpl MountParams
impl MountParams
Sourcefn to_mount_options(
&self,
fds: Vec<OwnedFd>,
) -> Result<MountOptions, RepositoryError>
fn to_mount_options( &self, fds: Vec<OwnedFd>, ) -> Result<MountOptions, RepositoryError>
Build [MountOptions] from these params, consuming the expected fds.